﻿using System;
using System.Windows.Forms;
using System.Drawing;
using GraphicsSwitcher;

namespace SwitcherTest
{
    static class Program
    {
        public static NotifyIcon SwitcherNotifyIcon;

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);

            //Create switcher context menu
            ContextMenu swContextMenu = new ContextMenu();
            swContextMenu.MenuItems.Add("Exit", ExitHandler);

            //Create switcher notify icon
            SwitcherNotifyIcon = new NotifyIcon();
            SwitcherNotifyIcon.Icon = new Icon("icon.ico");
            SwitcherNotifyIcon.Visible = true;
            SwitcherNotifyIcon.Text = "Graphics switcher";
            SwitcherNotifyIcon.ContextMenu = swContextMenu;

            //Create switcher and run application loop
            try
            {
                using (Switcher switcher = new Switcher())
                {
                    switcher.OnGraphicsSwitch += new GraphicsSwitchedDelegate(switcher_OnGraphicsSwitch);
                    Application.Run();
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(string.Format("Critical error in GraphicsSwitcher\n\n{0}\n\n{1}", e.Message, e.StackTrace));
            }

            SwitcherNotifyIcon.Dispose();
        }

        static void switcher_OnGraphicsSwitch(GraphicsAdapterType activeAdapter)
        {
            SwitcherNotifyIcon.Text = string.Format("Graphics switcher ({0})", activeAdapter == GraphicsAdapterType.Dedicated ? "dedicated" : "integrated");
        }

        public static void ExitHandler(Object sender, EventArgs e)
        {
            //End application
            Application.Exit();
        }
    }
}
